package com.jiuqi.util;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.jiuqi.util.Base64;
import com.jiuqi.util.IniFile;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

public abstract class CustomIniFile implements IniFile {
  public void writeInteger(String section, String ident, Integer value) {
    writeString(section, ident, (value == null) ? "0" : value.toString());
  }
  
  public void writeint(String section, String ident, int value) {
    writeString(section, ident, Integer.toString(value));
  }
  
  public void writeLong(String section, String ident, Long value) {
    writeString(section, ident, (value == null) ? "0" : value.toString());
  }
  
  public void writelong(String section, String ident, long value) {
    writeString(section, ident, Long.toString(value));
  }
  
  public void writeDouble(String section, String ident, Double value) {
    writeString(section, ident, (value == null) ? "0" : value.toString());
  }
  
  public void writedouble(String section, String ident, double value) {
    writeString(section, ident, Double.toString(value));
  }
  
  public void writeFloat(String section, String ident, Float value) {
    writeString(section, ident, (value == null) ? "0" : value.toString());
  }
  
  public void writefloat(String section, String ident, float value) {
    writeString(section, ident, Float.toString(value));
  }
  
  public void writeBoolean(String section, String ident, Boolean value) {
    writeString(section, ident, (value == null) ? "0" : (value.booleanValue() ? "1" : "0"));
  }
  
  public void writeboolean(String section, String ident, boolean value) {
    writeBoolean(section, ident, new Boolean(value));
  }
  
  public void writeBytes(String section, String ident, byte[] value) {
    String s = (value == null) ? "" : new String(Base64.byteArrayToBase64(value));
    writeString(section, ident, s);
  }
  
  public Integer readInteger(String section, String ident, Integer defvalue) {
    String s = readString(section, ident, "");
    if (s == null || s.equals(""))
      return defvalue; 
    return new Integer(s);
  }
  
  public int readint(String section, String ident, int defvalue) {
    return readInteger(section, ident, new Integer(defvalue)).intValue();
  }
  
  public Long readLong(String section, String ident, Long defvalue) {
    String s = readString(section, ident, "");
    if (s == null || s.equals(""))
      return defvalue; 
    return new Long(s);
  }
  
  public long readlong(String section, String ident, long defvalue) {
    return readLong(section, ident, new Long(defvalue)).longValue();
  }
  
  public Double readDouble(String section, String ident, Double defvalue) {
    String s = readString(section, ident, "");
    if (s == null || s.equals(""))
      return defvalue; 
    return new Double(s);
  }
  
  public double readdouble(String section, String ident, double defvalue) {
    return readDouble(section, ident, new Double(defvalue)).doubleValue();
  }
  
  public Boolean readBoolean(String section, String ident, Boolean defvalue) {
    return new Boolean(readboolean(section, ident, (defvalue == null) ? false : defvalue.booleanValue()));
  }
  
  public boolean readboolean(String section, String ident, boolean defvalue) {
    String s = readString(section, ident, "");
    return (s == null || s.equals("")) ? defvalue : (!s.equals("0"));
  }
  
  public byte[] readBytes(String section, String ident, byte[] defvalue) {
    String s = readString(section, ident, "");
    return Base64.base64ToByteArray(s);
  }
  
  public byte[] getBytes() {
    ByteArrayOutputStream stream = new ByteArrayOutputStream();
    saveToStream(stream);
    return stream.toByteArray();
  }
  
  public void setBytes(byte[] value) {
    ByteArrayInputStream stream = new ByteArrayInputStream(value);
    loadFromStream(stream);
  }
}
